@@ -6,9 +6,9 @@ Type annotations for s3outposts service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_s3outposts.literals import EndpointStatusType
+    from mypy_boto3_s3outposts.literals import EndpointAccessTypeType
 
-    data: EndpointStatusType = "AVAILABLE"
+    data: EndpointAccessTypeType = "CustomerOwnedIp"
     ```
 """
 import sys
@@ -19,8 +19,9 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("EndpointStatusType", "ListEndpointsPaginatorName")
+__all__ = ("EndpointAccessTypeType", "EndpointStatusType", "ListEndpointsPaginatorName")
 
 
-EndpointStatusType = Literal["AVAILABLE", "PENDING"]
+EndpointAccessTypeType = Literal["CustomerOwnedIp", "Private"]
+EndpointStatusType = Literal["Available", "Deleting", "Pending"]
 ListEndpointsPaginatorName = Literal["list_endpoints"]
